==> pandoc-citeproc-0.17.0.1-7-x86_64.pkg.tar.zst: usr/share/haskell/register/pandoc-citeproc.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 pandoc-citeproc
version:              0.17.0.1
visibility:           public
id:                   pandoc-citeproc-0.17.0.1-GC95iXhOnmsCVEtD19DBKW
key:                  pandoc-citeproc-0.17.0.1-GC95iXhOnmsCVEtD19DBKW
license:              BSD-3-Clause
maintainer:           jgm@berkeley.edu
author:               John MacFarlane, Andrea Rossato
homepage:             https://github.com/jgm/pandoc-citeproc
synopsis:             Supports using pandoc with citeproc
description:
    The pandoc-citeproc library supports automatic
    generation of citations and a bibliography in pandoc
    documents using the Citation Style Language (CSL)
    macro language. More details on CSL can be found at
    <http://citationstyles.org/>.

    In addition to a library, the package includes
    an executable, pandoc-citeproc, which works as a pandoc
    filter and also has a mode for converting bibliographic
    databases into CSL JSON and pandoc YAML metadata formats.

    pandoc-citeproc originated as a fork of Andrea
    Rossato'\''s citeproc-hs.

category:             Text
abi:                  01129d23493a494b3e901882a13fd98f
exposed:              True
exposed-modules:
    Text.CSL Text.CSL.Data Text.CSL.Eval Text.CSL.Eval.Common
    Text.CSL.Eval.Date Text.CSL.Eval.Names Text.CSL.Eval.Output
    Text.CSL.Exception Text.CSL.Input.Bibtex Text.CSL.Input.Bibutils
    Text.CSL.Output.Pandoc Text.CSL.Output.Plain Text.CSL.Pandoc
    Text.CSL.Parser Text.CSL.Proc Text.CSL.Proc.Collapse
    Text.CSL.Proc.Disamb Text.CSL.Reference Text.CSL.Style

hidden-modules:
    Text.CSL.Util Paths_pandoc_citeproc Text.CSL.Compat.Pandoc

import-dirs:          /usr/lib/ghc-8.10.1/site-local/pandoc-citeproc-0.17.0.1
library-dirs:         /usr/lib/ghc-8.10.1/site-local/pandoc-citeproc-0.17.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/pandoc-citeproc
hs-libraries:         HSpandoc-citeproc-0.17.0.1-GC95iXhOnmsCVEtD19DBKW
depends:
    HsYAML-0.2.1.0-1iMXs7T40JO6f7NQBCLMGs
    HsYAML-aeson-0.2.0.0-3Pu2eXA84e1ErDXrwIont0
    aeson-1.5.2.0-Dn5yhgMBsP9BMfGA2vLCmV base-4.14.0.0
    bytestring-0.10.10.0 containers-0.6.2.1
    data-default-0.7.1.1-HK1i3srOqHq9O9FnmDlpMG directory-1.3.6.0
    filepath-1.4.2.1 hs-bibutils-6.10.0.0-LmWLFgCg1wr45t3j8HNnBn
    mtl-2.2.2 network-3.1.1.1-GOd6U5iJ5goI00wUhGxCqR
    old-locale-1.0.0.7-He1fhgasqBf2zFT9zlaLle
    pandoc-2.9.2.1-3gkOQ7z3khmLS3M4B9NXEX
    pandoc-types-1.20-Gnsc6uDEGKLBdgDpsKvMsd parsec-3.1.14.0
    setenv-0.1.1.3-Eo6B1VGImNX7D6FUipT4ii
    split-0.2.3.4-I2Voq0QcJK5FrKDioOF6gT
    syb-0.7.1-6kfNxsXCCuQCrpdoMzyi8K
    tagsoup-0.14.8-8wL7k6OlnD6FMRsPKyYQRU text-1.2.3.2
    text-icu-0.7.0.1-2FtDbQqfo8wBAkk6I28n5G time-1.9.3
    unordered-containers-0.2.11.0-HkHTKJ34jxLBLVmLFyIg2F
    vector-0.12.1.2-2820kU4E8Rq2FpOG9Xf2aE
    xml-conduit-1.9.0.0-16tzLdknZivDIQ2FApSLA2
    yaml-0.11.4.0-Jc07gJIzUs53gnMkvYIIh2

haddock-interfaces:   /usr/share/doc/pandoc-citeproc/html/pandoc-citeproc.haddock
haddock-html:         /usr/share/doc/pandoc-citeproc/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> pandoc-citeproc-0.17.0.1-9-x86_64.pkg.tar.zst: usr/share/haskell/register/pandoc-citeproc.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 pandoc-citeproc
version:              0.17.0.1
visibility:           public
id:                   pandoc-citeproc-0.17.0.1-LqDOtHihYi8H99jPfIWXQk
key:                  pandoc-citeproc-0.17.0.1-LqDOtHihYi8H99jPfIWXQk
license:              BSD-3-Clause
maintainer:           jgm@berkeley.edu
author:               John MacFarlane, Andrea Rossato
homepage:             https://github.com/jgm/pandoc-citeproc
synopsis:             Supports using pandoc with citeproc
description:
    The pandoc-citeproc library supports automatic
    generation of citations and a bibliography in pandoc
    documents using the Citation Style Language (CSL)
    macro language. More details on CSL can be found at
    <http://citationstyles.org/>.

    In addition to a library, the package includes
    an executable, pandoc-citeproc, which works as a pandoc
    filter and also has a mode for converting bibliographic
    databases into CSL JSON and pandoc YAML metadata formats.

    pandoc-citeproc originated as a fork of Andrea
    Rossato'\''s citeproc-hs.

category:             Text
abi:                  dd9899976399073876d24bd16a86d178
exposed:              True
exposed-modules:
    Text.CSL Text.CSL.Data Text.CSL.Eval Text.CSL.Eval.Common
    Text.CSL.Eval.Date Text.CSL.Eval.Names Text.CSL.Eval.Output
    Text.CSL.Exception Text.CSL.Input.Bibtex Text.CSL.Input.Bibutils
    Text.CSL.Output.Pandoc Text.CSL.Output.Plain Text.CSL.Pandoc
    Text.CSL.Parser Text.CSL.Proc Text.CSL.Proc.Collapse
    Text.CSL.Proc.Disamb Text.CSL.Reference Text.CSL.Style

hidden-modules:
    Text.CSL.Util Paths_pandoc_citeproc Text.CSL.Compat.Pandoc

import-dirs:          /usr/lib/ghc-8.10.1/site-local/pandoc-citeproc-0.17.0.1
library-dirs:         /usr/lib/ghc-8.10.1/site-local/pandoc-citeproc-0.17.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/pandoc-citeproc
hs-libraries:         HSpandoc-citeproc-0.17.0.1-LqDOtHihYi8H99jPfIWXQk
depends:
    HsYAML-0.2.1.0-Gu0BV1ygSId8Qpozs6OZAW
    HsYAML-aeson-0.2.0.0-CV38RB24AKi5oCf8OWjJ5k
    aeson-1.5.2.0-7cPnEEpM6rgJJrGq6G7thP base-4.14.0.0
    bytestring-0.10.10.0 containers-0.6.2.1
    data-default-0.7.1.1-I5ttmgUOL407qEVhfvYDbu directory-1.3.6.0
    filepath-1.4.2.1 hs-bibutils-6.10.0.0-LmWLFgCg1wr45t3j8HNnBn
    mtl-2.2.2 network-3.1.1.1-21cfXONzmdN6SdhuDmk3jf
    old-locale-1.0.0.7-He1fhgasqBf2zFT9zlaLle
    pandoc-2.9.2.1-J7aE6efH7WFIuRPGtiglYS
    pandoc-types-1.20-Bn4tbzYhbJpHhx5skgqNon parsec-3.1.14.0
    setenv-0.1.1.3-Eo6B1VGImNX7D6FUipT4ii
    split-0.2.3.4-KFB0j5BVyxJ5KO1OFlvlff
    syb-0.7.1-6kfNxsXCCuQCrpdoMzyi8K
    tagsoup-0.14.8-8lRlkhRMkUXHLNPwI9W32R text-1.2.3.2
    text-icu-0.7.0.1-2FtDbQqfo8wBAkk6I28n5G time-1.9.3
    unordered-containers-0.2.11.0-4xXgRDqRkAy1dBzEEXx9oz
    vector-0.12.1.2-H0z3zqOucdK6qK7YVRJGW2
    xml-conduit-1.9.0.0-IkYXETfNC6GBOaGM5faGq0
    yaml-0.11.4.0-6PKOctRFUqYHUFHZe7QyVF

haddock-interfaces:   /usr/share/doc/pandoc-citeproc/html/pandoc-citeproc.haddock
haddock-html:         /usr/share/doc/pandoc-citeproc/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
